import { Injectable, ɵɵdefineInjectable, EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import { diff_match_patch } from 'diff-match-patch';
import { Diff2Html } from 'diff2html';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-diff2html.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxDiff2htmlService {
    constructor() { }
    /**
     * @param {?} text1
     * @param {?} text2
     * @param {?=} filename
     * @return {?}
     */
    getDiff(text1, text2, filename = '') {
        // Get diff
        /** @type {?} */
        const dmp = new diff_match_patch();
        /** @type {?} */
        const chars = dmp.diff_linesToChars_(text1, text2);
        /** @type {?} */
        const lineText1 = chars.chars1;
        /** @type {?} */
        const lineText2 = chars.chars2;
        /** @type {?} */
        const lineArray = chars.lineArray;
        /** @type {?} */
        const diffs = dmp.diff_main(lineText1, lineText2, false);
        dmp.diff_charsToLines_(diffs, lineArray);
        /** @type {?} */
        const patchMake = dmp.patch_make(text1, diffs);
        /** @type {?} */
        const patchToText = dmp.patch_toText(patchMake);
        // console.info(patchToText);
        // Make it look more like a unified diff style
        // ToDo: find a non tricky way to do this
        /** @type {?} */
        let lines = patchToText.split("\n");
        lines.forEach((/**
         * @param {?} line
         * @param {?} index
         * @return {?}
         */
        (line, index) => {
            if (line.startsWith('-')) {
                lines[index] = line.replace(/%0A(.)/g, "%0A-$1");
            }
            else if (line.startsWith('+')) {
                lines[index] = line.replace(/%0A(.)/g, "%0A+$1");
            }
        }));
        /** @type {?} */
        const unifiedDiff = lines.join("\n");
        // console.info(unifiedDiff);
        /** @type {?} */
        const strInput = "--- " + filename + " \n+++ " + filename + " \n" + unifiedDiff;
        /** @type {?} */
        const diff = decodeURIComponent(strInput);
        // console.info(diff);
        // Return diff
        return diff;
    }
    /**
     * @param {?} diff
     * @param {?=} format
     * @param {?=} style
     * @return {?}
     */
    diffToHTML(diff, format = 'line-by-line', style = 'word') {
        return Diff2Html.getPrettyHtml(diff, {
            inputFormat: 'diff',
            matching: 'lines',
            outputFormat: format,
            diffStyle: style
        });
    }
}
NgxDiff2htmlService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
NgxDiff2htmlService.ctorParameters = () => [];
/** @nocollapse */ NgxDiff2htmlService.ngInjectableDef = ɵɵdefineInjectable({ factory: function NgxDiff2htmlService_Factory() { return new NgxDiff2htmlService(); }, token: NgxDiff2htmlService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-diff2html.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxDiff2htmlComponent {
    /**
     * @param {?} diffService
     */
    constructor(diffService) {
        this.diffService = diffService;
        this.filename = '';
        this.format = 'line-by-line';
        this.style = 'word';
        this.diffChange = new EventEmitter();
        this.diff = null;
        this.diffHTML = null;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.getDiff();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        //console.log(changes);
        if (this.propHasChanged(changes.left) || this.propHasChanged(changes.right)) {
            this.getDiff();
        }
        else if (this.propHasChanged(changes.style) || this.propHasChanged(changes.format)) {
            this.refreshDiffHTML();
        }
    }
    /**
     * @private
     * @param {?} change
     * @return {?}
     */
    propHasChanged(change) {
        return change && !change.isFirstChange() && change.currentValue !== change.previousValue;
    }
    /**
     * @return {?}
     */
    getDiff() {
        this.diff = this.diffService.getDiff(this.left, this.right, this.filename);
        this.refreshDiffHTML();
        this.diffChange.emit(this.diff);
    }
    /**
     * @return {?}
     */
    refreshDiffHTML() {
        this.diffHTML = this.diffService.diffToHTML(this.diff, this.format, this.style);
    }
}
NgxDiff2htmlComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-diff2html',
                template: `
    <div [innerHtml]="diffHTML"></div>
  `
            }] }
];
/** @nocollapse */
NgxDiff2htmlComponent.ctorParameters = () => [
    { type: NgxDiff2htmlService }
];
NgxDiff2htmlComponent.propDecorators = {
    left: [{ type: Input }],
    right: [{ type: Input }],
    filename: [{ type: Input }],
    format: [{ type: Input }],
    style: [{ type: Input }],
    diffChange: [{ type: Output }]
};
if (false) {
    /**
     * @type {?}
     * @private
     */
    NgxDiff2htmlComponent.prototype.left;
    /**
     * @type {?}
     * @private
     */
    NgxDiff2htmlComponent.prototype.right;
    /**
     * @type {?}
     * @private
     */
    NgxDiff2htmlComponent.prototype.filename;
    /**
     * @type {?}
     * @private
     */
    NgxDiff2htmlComponent.prototype.format;
    /**
     * @type {?}
     * @private
     */
    NgxDiff2htmlComponent.prototype.style;
    /** @type {?} */
    NgxDiff2htmlComponent.prototype.diffChange;
    /**
     * @type {?}
     * @private
     */
    NgxDiff2htmlComponent.prototype.diff;
    /** @type {?} */
    NgxDiff2htmlComponent.prototype.diffHTML;
    /**
     * @type {?}
     * @private
     */
    NgxDiff2htmlComponent.prototype.diffService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-diff2html.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxDiff2htmlModule {
}
NgxDiff2htmlModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NgxDiff2htmlComponent
                ],
                imports: [],
                exports: [
                    NgxDiff2htmlComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-diff2html.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-diff2html.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxDiff2htmlComponent, NgxDiff2htmlModule, NgxDiff2htmlService };
//# sourceMappingURL=ngx-diff2html.js.map
